@@ -17,7 +17,7 @@ from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
-from .literals import TypeType
+from .literals import AssetTypeType, TypeType
 from .paginator import (
     ListDataSetRevisionsPaginator,
     ListDataSetsPaginator,
@@ -80,7 +80,7 @@ class Exceptions:
 
 class DataExchangeClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html)
     """
 
@@ -96,7 +96,7 @@ class DataExchangeClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#can_paginate)
         """
 
@@ -104,14 +104,14 @@ class DataExchangeClient(BaseClient):
         """
         This operation cancels a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.cancel_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.cancel_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#cancel_job)
         """
 
     def create_data_set(
         self,
         *,
-        AssetType: Literal["S3_SNAPSHOT"],
+        AssetType: AssetTypeType,
         Description: str,
         Name: str,
         Tags: Mapping[str, str] = ...
@@ -119,7 +119,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation creates a data set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.create_data_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.create_data_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#create_data_set)
         """
 
@@ -129,7 +129,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation creates an event action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.create_event_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.create_event_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#create_event_action)
         """
 
@@ -139,7 +139,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation creates a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.create_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.create_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#create_job)
         """
 
@@ -149,7 +149,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation creates a revision for a data set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.create_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.create_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#create_revision)
         """
 
@@ -157,7 +157,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation deletes an asset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.delete_asset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.delete_asset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#delete_asset)
         """
 
@@ -165,7 +165,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation deletes a data set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.delete_data_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.delete_data_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#delete_data_set)
         """
 
@@ -173,7 +173,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation deletes the event action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.delete_event_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.delete_event_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#delete_event_action)
         """
 
@@ -181,7 +181,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation deletes a revision.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.delete_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.delete_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#delete_revision)
         """
 
@@ -195,7 +195,7 @@ class DataExchangeClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#generate_presigned_url)
         """
 
@@ -205,7 +205,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation returns information about an asset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.get_asset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.get_asset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#get_asset)
         """
 
@@ -213,7 +213,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation returns information about a data set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.get_data_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.get_data_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#get_data_set)
         """
 
@@ -221,7 +221,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation retrieves information about an event action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.get_event_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.get_event_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#get_event_action)
         """
 
@@ -229,7 +229,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation returns information about a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.get_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.get_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#get_job)
         """
 
@@ -237,7 +237,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation returns information about a revision.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.get_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.get_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#get_revision)
         """
 
@@ -248,7 +248,7 @@ class DataExchangeClient(BaseClient):
         This operation lists a data set's revisions sorted by CreatedAt in descending
         order.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.list_data_set_revisions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.list_data_set_revisions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_data_set_revisions)
         """
 
@@ -258,7 +258,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation lists your data sets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.list_data_sets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.list_data_sets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_data_sets)
         """
 
@@ -268,7 +268,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation lists your event actions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.list_event_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.list_event_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_event_actions)
         """
 
@@ -283,7 +283,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation lists your jobs sorted by CreatedAt in descending order.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.list_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.list_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_jobs)
         """
 
@@ -294,7 +294,7 @@ class DataExchangeClient(BaseClient):
         This operation lists a revision's assets sorted alphabetically in descending
         order.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.list_revision_assets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.list_revision_assets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_revision_assets)
         """
 
@@ -302,7 +302,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation lists the tags on the resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_tags_for_resource)
         """
 
@@ -310,7 +310,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation starts a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.start_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.start_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#start_job)
         """
 
@@ -318,7 +318,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation tags a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#tag_resource)
         """
 
@@ -326,7 +326,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation removes one or more tags from a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#untag_resource)
         """
 
@@ -336,7 +336,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation updates an asset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.update_asset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.update_asset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#update_asset)
         """
 
@@ -346,7 +346,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation updates a data set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.update_data_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.update_data_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#update_data_set)
         """
 
@@ -356,7 +356,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation updates the event action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.update_event_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.update_event_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#update_event_action)
         """
 
@@ -366,7 +366,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation updates a revision.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Client.update_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Client.update_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#update_revision)
         """
 
@@ -375,14 +375,14 @@ class DataExchangeClient(BaseClient):
         self, operation_name: Literal["list_data_set_revisions"]
     ) -> ListDataSetRevisionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSetRevisions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSetRevisions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listdatasetrevisionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_data_sets"]) -> ListDataSetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listdatasetspaginator)
         """
 
@@ -391,14 +391,14 @@ class DataExchangeClient(BaseClient):
         self, operation_name: Literal["list_event_actions"]
     ) -> ListEventActionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Paginator.ListEventActions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Paginator.ListEventActions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listeventactionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Paginator.ListJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Paginator.ListJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listjobspaginator)
         """
 
@@ -407,6 +407,6 @@ class DataExchangeClient(BaseClient):
         self, operation_name: Literal["list_revision_assets"]
     ) -> ListRevisionAssetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.63/reference/services/dataexchange.html#DataExchange.Paginator.ListRevisionAssets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/dataexchange.html#DataExchange.Paginator.ListRevisionAssets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listrevisionassetspaginator)
         """
