@@ -8,7 +8,7 @@ Usage::
     ```python
     from mypy_boto3_dataexchange.literals import AssetTypeType
 
-    data: AssetTypeType = "S3_SNAPSHOT"
+    data: AssetTypeType = "REDSHIFT_DATA_SHARE"
     ```
 """
 import sys
@@ -38,7 +38,7 @@ __all__ = (
 )
 
 
-AssetTypeType = Literal["S3_SNAPSHOT"]
+AssetTypeType = Literal["REDSHIFT_DATA_SHARE", "S3_SNAPSHOT"]
 CodeType = Literal[
     "ACCESS_DENIED_EXCEPTION",
     "INTERNAL_SERVER_EXCEPTION",
@@ -48,7 +48,9 @@ CodeType = Literal[
     "SERVICE_QUOTA_EXCEEDED_EXCEPTION",
     "VALIDATION_EXCEPTION",
 ]
-JobErrorLimitNameType = Literal["Asset size in GB", "Assets per revision"]
+JobErrorLimitNameType = Literal[
+    "Amazon Redshift datashare assets per revision", "Asset size in GB", "Assets per revision"
+]
 JobErrorResourceTypesType = Literal["ASSET", "DATA_SET", "REVISION"]
 ListDataSetRevisionsPaginatorName = Literal["list_data_set_revisions"]
 ListDataSetsPaginatorName = Literal["list_data_sets"]
@@ -62,6 +64,7 @@ TypeType = Literal[
     "EXPORT_ASSETS_TO_S3",
     "EXPORT_ASSET_TO_SIGNED_URL",
     "EXPORT_REVISIONS_TO_S3",
+    "IMPORT_ASSETS_FROM_REDSHIFT_DATA_SHARES",
     "IMPORT_ASSETS_FROM_S3",
     "IMPORT_ASSET_FROM_SIGNED_URL",
 ]
